"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const quidproquo_core_1 = require("quidproquo-core");
const quidproquo_webserver_1 = require("quidproquo-webserver");
const awsNamingUtils_1 = require("../../../awsNamingUtils");
const getPagedItemsOverRange_1 = require("../../../logic/dynamo/getPagedItemsOverRange");
const getLogChildrenByFromCorrelation_1 = require("../../../logic/dynamo/getLogChildrenByFromCorrelation");
const readTextFile_1 = require("../../../logic/s3/readTextFile");
// TODO: Centralize this
const QPQ_LOG_BUCKET_NAME = 'logs';
const getAdminGetLogsActionProcessor = (qpqConfig) => {
    return ({ runtimeType, nextPageKey, startIsoDateTime, endIsoDateTime }) => __awaiter(void 0, void 0, void 0, function* () {
        const tableName = (0, awsNamingUtils_1.getQpqRuntimeResourceNameFromConfig)(QPQ_LOG_BUCKET_NAME, qpqConfig, 'log');
        const region = quidproquo_core_1.qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const response = yield (0, getPagedItemsOverRange_1.getPagedItemsOverRange)(tableName, region, runtimeType, startIsoDateTime, endIsoDateTime, nextPageKey);
        return (0, quidproquo_core_1.actionResult)(response);
    });
};
const getLogMetadataChildrenActionProcessor = (qpqConfig) => {
    return ({ correlationId }) => __awaiter(void 0, void 0, void 0, function* () {
        const tableName = (0, awsNamingUtils_1.getQpqRuntimeResourceNameFromConfig)(QPQ_LOG_BUCKET_NAME, qpqConfig, 'log');
        const region = quidproquo_core_1.qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const response = yield (0, getLogChildrenByFromCorrelation_1.getLogChildrenByFromCorrelation)(tableName, region, correlationId);
        return (0, quidproquo_core_1.actionResult)(response);
    });
};
const getAdminGetLogActionProcessor = (qpqConfig) => {
    return ({ correlationId }) => __awaiter(void 0, void 0, void 0, function* () {
        const bucketName = (0, awsNamingUtils_1.getQpqRuntimeResourceNameFromConfig)(QPQ_LOG_BUCKET_NAME, qpqConfig, 'log');
        const region = quidproquo_core_1.qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const logJson = yield (0, readTextFile_1.readTextFile)(bucketName, `${correlationId}.json`, region);
        const response = JSON.parse(logJson);
        return (0, quidproquo_core_1.actionResult)(response);
    });
};
exports.default = (qpqConfig) => {
    return {
        [quidproquo_webserver_1.AdminActionType.GetLogs]: getAdminGetLogsActionProcessor(qpqConfig),
        [quidproquo_webserver_1.AdminActionType.GetLog]: getAdminGetLogActionProcessor(qpqConfig),
        [quidproquo_webserver_1.AdminActionType.GetLogMetadataChildren]: getLogMetadataChildrenActionProcessor(qpqConfig),
    };
};
