"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createUser = exports.getUserAttributesFromCreateUserRequest = void 0;
const client_cognito_identity_provider_1 = require("@aws-sdk/client-cognito-identity-provider");
const authenticateUser_1 = require("./authenticateUser");
const setUserPassword_1 = require("./setUserPassword");
const cognitoAttributeMap = {
    email: 'email',
    emailVerified: 'email_verified',
    password: 'password',
    address: 'address',
    birthDate: 'birthdate',
    familyName: 'family_name',
    gender: 'gender',
    givenName: 'given_name',
    locale: 'locale',
    middleName: 'middle_name',
    name: 'name',
    nickname: 'nickname',
    phoneNumber: 'phone_number',
    picture: 'picture',
    preferredUsername: 'preferred_username',
    profile: 'profile',
    website: 'website',
    zoneInfo: 'zoneinfo',
};
const getUserAttributesFromCreateUserRequest = (createUserRequest) => {
    return Object.keys(createUserRequest)
        .map((key) => ({
        Name: cognitoAttributeMap[key],
        Value: `${createUserRequest[key]}`,
    }))
        .filter((attribute) => !!attribute.Value && attribute.Name !== 'password');
};
exports.getUserAttributesFromCreateUserRequest = getUserAttributesFromCreateUserRequest;
const createUser = (userPoolId, region, clientId, createUserRequest) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    const cognitoClient = new client_cognito_identity_provider_1.CognitoIdentityProviderClient({ region });
    const params = {
        UserPoolId: userPoolId,
        Username: createUserRequest.email,
        MessageAction: client_cognito_identity_provider_1.MessageActionType.SUPPRESS,
        DesiredDeliveryMediums: [client_cognito_identity_provider_1.DeliveryMediumType.EMAIL],
        UserAttributes: (0, exports.getUserAttributesFromCreateUserRequest)(createUserRequest),
        ForceAliasCreation: false,
    };
    if (createUserRequest.phoneNumber) {
        params.DesiredDeliveryMediums.push(client_cognito_identity_provider_1.DeliveryMediumType.SMS);
    }
    const response = yield cognitoClient.send(new client_cognito_identity_provider_1.AdminCreateUserCommand(params));
    const username = ((_a = response.User) === null || _a === void 0 ? void 0 : _a.Username) || '';
    // Set the user's password
    yield (0, setUserPassword_1.setUserPassword)(region, userPoolId, username, createUserRequest.password);
    // Authenticate the user
    const authResponse = yield (0, authenticateUser_1.authenticateUser)(userPoolId, clientId, region, username, createUserRequest.password);
    return authResponse;
});
exports.createUser = createUser;
